@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 =head1 NAME
 
@@ -105,7 +105,7 @@ Delete a sponsor.
 =cut
 
 sub Admin {
-    return  unless AccessUser(ADMIN);
+    return  unless AccessUser(EDITOR);
 
     if($cgiparams{doaction}) {
         if($cgiparams{doaction} eq 'Delete') { Delete(); }
@@ -116,7 +116,7 @@ sub Admin {
 }
 
 sub Add {
-    return  unless AccessUser(ADMIN);
+    return  unless AccessUser(EDITOR);
     $tvars{data} = {
         sponsor     => 'Sponsor',
         sponsorlink => ''
@@ -124,13 +124,13 @@ sub Add {
 }
 
 sub Edit {
-    return  unless AccessUser(ADMIN);
-    return  unless AuthorCheck('GetSponsorByID',$INDEXKEY,ADMIN);
+    return  unless AccessUser(EDITOR);
+    return  unless AuthorCheck('GetSponsorByID',$INDEXKEY,EDITOR);
 }
 
 sub Save {
-    return  unless AccessUser(ADMIN);
-    return  unless AuthorCheck('GetSponsorByID',$INDEXKEY,ADMIN);
+    return  unless AccessUser(EDITOR);
+    return  unless AuthorCheck('GetSponsorByID',$INDEXKEY,EDITOR);
 
     return  if FieldCheck(\@allfields,\@mandatory);
 
@@ -172,7 +172,7 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2002-2012 Barbie for Miss Barbell Productions
+  Copyright (C) 2002-2013 Barbie for Miss Barbell Productions
   All Rights Reserved.
 
   This module is free software; you can redistribute it and/or
